@@ -3,10 +3,11 @@
 #' @param from The first area from which to create a link
 #' @param to The second one
 #' @param propertiesLink a named list containing the link properties, e.g. hurdles-cost
-#' or transmission-capacities for example.
-#' @param dataLink a matrix with five column corresponding to : trans. capacity (direct)
-#' trans. capacity (indirect), impedances, hurdles cost (direct), hurdles cost (indirect).
-#' If \code{NULL} (default), a matrix whose rows are equal to \code{1, 1, 0, 0, 0} is set. See Details
+#' or transmission-capacities for example. See \code{\link{propertiesLinkOptions}}.
+#' @param dataLink For Antares v7, a matrix with eight column corresponding to : trans. capacity (direct)
+#' trans. capacity (indirect), hurdles cost (direct), hurdles cost (indirect), impedances, loop flow,
+#' PST min, PST max.
+#' If \code{NULL} (default), a matrix whose rows are equal to \code{1, 1, 0, 0, 0, 0, 0, 0} is set. See Details
 #' @param overwrite Logical, overwrite the previous between the two areas if exist
 #' @param opts
 #'   List of simulation parameters returned by the function
@@ -17,14 +18,20 @@
 #' So the areas are sorted before creating the link between them, and \code{dataLink} is
 #' rearranged to match the new order.
 #' 
-#' @details The five times-series are:
+#' @details The eight times-series are:
 #' \itemize{
 #'  \item{"NTC direct"}{the upstream-to-downstream capacity, in MW}
 #'  \item{"NTC indirect"}{the downstream-to-upstream capacity, in MW}
-#'  \item{"Impedances"}{virtual impedances that are used in economy simulations to give a physical meaning to raw outputs, when no binding constraints have been defined to enforce Kirchhoff's laws.}
 #'  \item{"Hurdle cost direct"}{an upstream-to-downstream transmission fee, in euro/MWh}
 #'  \item{"Hurdle cost indirect"}{a downstream-to-upstream transmission fee, in euro/MWh}
+#'  \item{"Impedances"}{virtual impedances that are used in economy simulations to give a physical meaning to raw outputs, when no binding constraints have been defined to enforce Kirchhoff's laws.}
+#'  \item{"Loop flow"}{amount of power flowing circularly though the grid when all “nodes” are perfectly balanced (no import and no export).}
+#'  \item{"PST min"}{lower bound of phase-shifting that can be reached by a PST installed on the link, if any.}
+#'  \item{"PST max"}{upper bound of phase-shifting that can be reached by a PST installed on the link, if any.}
 #' }
+#' NB: For Antares v7 the eight columns must conform to above order. For Antares v6, only five columns are 
+#' expected, and they must follow this other order: NTC direct, NTC indirect, Impedances, Hurdle cost direct,
+#' Hurdle cost indirect.
 #'
 #' @return An updated list containing various information about the simulation.
 #' @export
@@ -40,8 +47,16 @@
 createLink <- function(from, to, propertiesLink = propertiesLinkOptions(), dataLink = NULL, overwrite = FALSE, opts = antaresRead::simOptions()) {
   
   assertthat::assert_that(class(opts) == "simOptions")
-  if (!is.null(dataLink)) 
-    assertthat::assert_that(ncol(dataLink) == 5)
+  
+  v7 <- is_antares_v7(opts)
+  
+  if (!is.null(dataLink)) {
+    if (v7) {
+      assertthat::assert_that(ncol(dataLink) == 8)
+    } else {
+      assertthat::assert_that(ncol(dataLink) == 5)
+    }
+  }
   
   # control areas name
   # can be with some upper case (list.txt)
@@ -92,11 +107,17 @@ createLink <- function(from, to, propertiesLink = propertiesLinkOptions(), dataL
   )
   
   # initialization data
-  if (is.null(dataLink)) 
-    dataLink <- matrix(data = c(rep(1, 8760*2), rep(0, 8760*3)), ncol = 5)
+  if (is.null(dataLink)) {
+    if (v7) {
+      dataLink <- matrix(data = c(rep(1, 8760*2), rep(0, 8760*6)), ncol = 8)
+    } else {
+      dataLink <- matrix(data = c(rep(1, 8760*2), rep(0, 8760*3)), ncol = 5)
+    }
+  }
   
   if (!identical(areas, sort(areas))) {
-    dataLink <- dataLink[, c(2, 1, 3, 5, 4)]
+    dataLink[, 1:2] <- dataLink[, 2:1]
+    dataLink[, 4:5] <- dataLink[, 5:4]
   }
   
   utils::write.table(
@@ -121,6 +142,9 @@ createLink <- function(from, to, propertiesLink = propertiesLinkOptions(), dataL
 #' @param transmission_capacities Character, one of \code{enabled}, \code{ignore} or \code{infinite}, which is used to state whether 
 #' the capacities to consider are those indicated in 8760-hour arrays or 
 #' if zero or infinite values should be used instead (actual values / set to zero / set to infinite)
+#' @param asset_type Character, one of \code{ac}, \code{dc}, \code{gas}, \code{virt} or \code{other}. Used to
+#'   state whether the link is either an AC component (subject to Kirchhoff’s laws), a DC component, 
+#'   or another type of asset.
 #' @param display_comments Logical
 #' @param filter_synthesis Output synthesis
 #' @param filter_year_by_year Output year-by-year
@@ -133,13 +157,15 @@ createLink <- function(from, to, propertiesLink = propertiesLinkOptions(), dataL
 #' propertiesLinkOptions()
 #' }
 propertiesLinkOptions <- function(hurdles_cost = FALSE, 
-                           transmission_capacities = "enabled", 
+                           transmission_capacities = "enabled",
+                           asset_type = "ac",
                            display_comments = TRUE,
                            filter_synthesis = c("hourly", "daily", "weekly", "monthly", "annual"),
                            filter_year_by_year = c("hourly", "daily", "weekly", "monthly", "annual")) {
   list(
     `hurdles-cost` = hurdles_cost,
     `transmission-capacities` = transmission_capacities,
+    `asset-type` = asset_type,
     `display-comments` = display_comments,
     `filter-synthesis` = filter_synthesis,
     `filter-year-by-year` = filter_year_by_year
