@@ -10,6 +10,7 @@
 #' @export
 #' 
 #' @importFrom whisker whisker.render
+#' @importFrom utils unzip
 #'
 #' @examples
 #' \dontrun{
@@ -17,9 +18,7 @@
 #' createStudy("path/to/simulation")
 #' 
 #' }
-createStudy <- function(path, study_name = "my_study", antares_version = "6.0.0") {
-  if (antares_version != "6.0.0") 
-    warning("Only Antares version 6.0.0 is supported", call. = FALSE)
+createStudy <- function(path, study_name = "my_study", antares_version = "7.0.0") {
   if (!dir.exists(path)) {
     dir.create(path = path, recursive = TRUE)
   } else {
@@ -27,16 +26,21 @@ createStudy <- function(path, study_name = "my_study", antares_version = "6.0.0"
       path <- file.path(path, study_name)
     }
   }
-  statut <- file.copy(
-    from = list.files(path = system.file("newStudy", package = "antaresEditObject"), full.names = TRUE),
-    to = path, recursive = TRUE
-  )
-  to_delete <- list.files(path = path, pattern = "ANTARESEDITOBJECT_TODELETE", full.names = TRUE, recursive = TRUE)
-  unlink(to_delete)
+  if (antares_version < "6.5.0") {
+    statut <- file.copy(
+      from = list.files(path = system.file("newStudy", package = "antaresEditObject"), full.names = TRUE),
+      to = path, recursive = TRUE
+    )
+    to_delete <- list.files(path = path, pattern = "ANTARESEDITOBJECT_TODELETE", full.names = TRUE, recursive = TRUE)
+    unlink(to_delete)
+  } else {
+    statut <- unzip(zipfile = system.file("template-antares/antares-study-v7.zip", package = "antaresEditObject"), exdir = path)
+  }
   antares <- paste(readLines(con = file.path(path, "study.antares")), collapse = "\n")
   antares <- whisker::whisker.render(
     template = antares,
     data = list(
+      version = gsub(pattern = "\\.", replacement = "", x = antares_version),
       study_name = study_name,
       date_created = floor(as.numeric(Sys.time()))
     )
